tuplettools.make_tuplet_from_proportions_and_pair
=================================================

.. autofunction:: abjad.tools.tuplettools.make_tuplet_from_proportions_and_pair.make_tuplet_from_proportions_and_pair
